summaryrefslogtreecommitdiff
path: root/src/keydata.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/keydata.h')
-rw-r--r--src/keydata.h3
1 files changed, 2 insertions, 1 deletions
diff --git a/src/keydata.h b/src/keydata.h
index d9d584a6b..352f61f6a 100644
--- a/src/keydata.h
+++ b/src/keydata.h
@@ -53,7 +53,8 @@ namespace Input
GRP_OUTFIT = 8, // outfit key
GRP_GUI = 16, // gui key
GRP_MOVETOPOINT = 32, // move to point key
- GRP_GUICHAN = 64 // for guichan based controls
+ GRP_GUICHAN = 64, // for guichan based controls
+ GRP_REPEAT = 128 // repeat emulation keys
};
/**